from dataclasses import dataclass
from pathlib import Path

import requests


@dataclass
class Download:
    url: str
    quality: str
    filename: str

    def download(
        self,
        cookies: dict[str, str],
        destination_dir: Path,
        filename: str | None = None,
    ):
        """Downloads the episode into the directory @destination_dir. The cookies from @cookies are used
        during the request."""
        with requests.get(
            self.url,
            cookies=cookies,
            headers={
                "Referrer": self.url,
            },
            stream=True,
        ) as r:
            r.raise_for_status()

            fname = filename or self.filename
            with open(destination_dir / fname, "wb") as f:
                for chunk in r.iter_content(chunk_size=8196):
                    f.write(chunk)
